==> enterprisemodules-wls_config-3.0.21.tar.gz: enterprisemodules-wls_config-3.0.21/meta/wls_jms_connection_factory.py <==
username      = sys.argv[1]
password      = sys.argv[2]
url           = sys.argv[3]

connect(username, password, url)

execfile('/vagrant/files/wlst/common.py.erb')
execfile('/vagrant/meta/get_properties.py')

print 'base properties'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/ConnectionFactories/cf','wls_jms_connection_factory')  # All default properties
print 'base SecurityParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/ConnectionFactories/cf/SecurityParams/cf','wls_jms_connection_factory', 'security_', 'SecurityParams/%{connection_factory_name}/')  # All default properties
print 'base ClientParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/ConnectionFactories/cf/ClientParams/cf','wls_jms_connection_factory', 'client_', 'ClientParams/%{connection_factory_name}/')  # All default properties
print 'base DefaultDeliveryParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/ConnectionFactories/cf/DefaultDeliveryParams/cf','wls_jms_connection_factory', 'delivery_', 'DefaultDeliveryParams/%{connection_factory_name}/')  # All default properties
print 'base LoadBalancingParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/ConnectionFactories/cf/LoadBalancingParams/cf','wls_jms_connection_factory', 'lb_', 'LoadBalancingParams/%{connection_factory_name}/')  # All default properties
print 'base TransactionParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/ConnectionFactories/cf/TransactionParams/cf','wls_jms_connection_factory', 'transaction_', 'TransactionParams/%{connection_factory_name}/')  # All default properties
print 'base FlowControlParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/ConnectionFactories/cf/FlowControlParams/cf','wls_jms_connection_factory', 'flow_', 'FlowControlParams/%{connection_factory_name}/')  # All default properties

==> enterprisemodules-wls_config-3.3.15.tar.gz: enterprisemodules-wls_config-3.3.15/meta/wls_jms_connection_factory.py <==
username      = sys.argv[1]
password      = sys.argv[2]
url           = sys.argv[3]

connect(username, password, url)

execfile('/etc/puppetlabs/code/environments/production/modules/wls_config//lib/puppet/provider/wls_config/wlst/templates/common.py.erb')
execfile('/etc/puppetlabs/code/environments/production/modules/wls_config/meta/get_properties.py')

print 'base properties'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/ConnectionFactories/cf','wls_jms_connection_factory')  # All default properties
print 'base SecurityParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/ConnectionFactories/cf/SecurityParams/cf','wls_jms_connection_factory', 'security_', 'SecurityParams/%{connection_factory_name}/')  # All default properties
print 'base ClientParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/ConnectionFactories/cf/ClientParams/cf','wls_jms_connection_factory', 'client_', 'ClientParams/%{connection_factory_name}/')  # All default properties
print 'base DefaultDeliveryParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/ConnectionFactories/cf/DefaultDeliveryParams/cf','wls_jms_connection_factory', 'delivery_', 'DefaultDeliveryParams/%{connection_factory_name}/')  # All default properties
print 'base LoadBalancingParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/ConnectionFactories/cf/LoadBalancingParams/cf','wls_jms_connection_factory', 'lb_', 'LoadBalancingParams/%{connection_factory_name}/')  # All default properties
print 'base TransactionParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/ConnectionFactories/cf/TransactionParams/cf','wls_jms_connection_factory', 'transaction_', 'TransactionParams/%{connection_factory_name}/')  # All default properties
print 'base FlowControlParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/ConnectionFactories/cf/FlowControlParams/cf','wls_jms_connection_factory', 'flow_', 'FlowControlParams/%{connection_factory_name}/')  # All default properties
